@@ -1,7 +1,7 @@
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // TGUI - Texus' Graphical User Interface
-// Copyright (C) 2012-2023 Bruno Van de Velde (vdv_b@tgui.eu)
+// Copyright (C) 2012-2024 Bruno Van de Velde (vdv_b@tgui.eu)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -22,11 +22,9 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #ifndef TGUI_SPIN_CONTROL_HPP
 #define TGUI_SPIN_CONTROL_HPP
 
-
 #include <TGUI/SubwidgetContainer.hpp>
 #include <TGUI/Widgets/SpinButton.hpp>
 #include <TGUI/Widgets/EditBox.hpp>
@@ -47,7 +45,6 @@ TGUI_MODULE_EXPORT namespace tgui
 
         static constexpr const char StaticWidgetType[] = "SpinControl"; //!< Type name of the widget
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @internal
         /// @brief Constructor
@@ -57,31 +54,26 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         SpinControl(const char* typeName = StaticWidgetType, bool initRenderer = true);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Copy constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         SpinControl(const SpinControl& copy);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Move constructor
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         SpinControl(SpinControl&& copy) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of copy assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         SpinControl& operator= (const SpinControl& right);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Overload of move assignment operator
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         SpinControl& operator= (SpinControl&& right) noexcept;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Creates a new spin button widget
         ///
@@ -95,7 +87,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static SpinControl::Ptr create(float min = 0.0f, float max = 10.0f, float value = 0.0f, unsigned int decimal = 0, float step = 1.0f);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Makes a copy of another spin control
         ///
@@ -105,7 +96,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD static SpinControl::Ptr copy(const SpinControl::ConstPtr& SpinCtrl);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer of spin buttons part of widget
         /// @return Temporary pointer to the renderer that may be shared with other widgets using the same renderer
@@ -120,7 +110,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD SpinButtonRenderer* getSpinButtonRenderer();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer of edit box part of widget
         /// @return Temporary pointer to the renderer that may be shared with other widgets using the same renderer
@@ -128,7 +117,6 @@ TGUI_MODULE_EXPORT namespace tgui
         TGUI_NODISCARD EditBoxRenderer* getSpinTextSharedRenderer();
         TGUI_NODISCARD const EditBoxRenderer* getSpinTextSharedRenderer() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the renderer of edit box part of widget
         /// @return Temporary pointer to the renderer
@@ -136,7 +124,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD EditBoxRenderer* getSpinTextRenderer();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the size of the spin control
         ///
@@ -145,7 +132,6 @@ TGUI_MODULE_EXPORT namespace tgui
         void setSize(const Layout2d& size) override;
         using SubwidgetContainer::setSize;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets a minimum value
         ///
@@ -156,7 +142,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMinimum(float minimum);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the minimum value
         ///
@@ -166,7 +151,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getMinimum() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Sets a maximum value
         ///
@@ -177,7 +161,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setMaximum(float maximum);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the maximum value
         ///
@@ -187,7 +170,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getMaximum() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the current value
         ///
@@ -199,7 +181,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool setValue(float value);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the current value
         ///
@@ -209,7 +190,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getValue() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes how much the value changes on each arrow press
         /// @param step  The new step size
@@ -217,7 +197,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setStep(float step);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the number of positions the thumb advances with each move
         /// @return The current step size
@@ -227,7 +206,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD float getStep() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes the number of decimal places to display
         /// @param decimalPlaces The new number of decimal places
@@ -236,7 +214,6 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setDecimalPlaces(unsigned int decimalPlaces);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns the number of decimal places to display
         /// @return The current number of decimal places
@@ -246,20 +223,35 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD unsigned int getDecimalPlaces() const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Changes whether the spin button width equals the heigh or the widget or only half of the height (default)
         /// @param useWideArrows  Should the width of the spin button equal its height instead of half the height?
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        void setUseWideArrows(bool useWideArrows);
-
+        TGUI_DEPRECATED("Use setSpinButtonWidth(\"100%\") or setSpinButtonWidth(\"50%\") instead") void setUseWideArrows(bool useWideArrows);
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Returns whether the spin button width equals the heigh or the widget or only half of the height (default)
         /// @return Does the width of the spin button equal its height instead of half the height?
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-        TGUI_NODISCARD bool getUseWideArrows() const;
+        TGUI_DEPRECATED("Use getSpinButtonWidth() instead") TGUI_NODISCARD bool getUseWideArrows() const;
 
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Changes the width of the spin button (i.e. width of the arrows that are shown next to the edit box)
+        ///
+        /// @param width  Width of the spin button
+        ///
+        /// When the width is a relative value, then it is relative to the height of the spin control.
+        ///
+        /// @since TGUI 1.6
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        void setSpinButtonWidth(AbsoluteOrRelativeValue width);
+
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        /// @brief Returns the width of the spin button (i.e. width of the arrows that are shown next to the edit box)
+        /// @return Width of the spin button
+        /// @since TGUI 1.6
+        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+        float getSpinButtonWidth() const;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
@@ -275,25 +267,21 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Signal& getSignal(String signalName) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Makes a copy of the widget
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD Widget::Ptr clone() const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Saves the widget as a tree node in order to save it to a file
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         TGUI_NODISCARD std::unique_ptr<DataIO::Node> save(SavingRenderersMap& renderers) const override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         /// @brief Loads the widget from a tree of nodes
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void load(const std::unique_ptr<DataIO::Node>& node, const LoadingRenderersMap& renderers) override;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
 
@@ -302,30 +290,27 @@ TGUI_MODULE_EXPORT namespace tgui
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void init();
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Checks whether a value lies between the minimum and maximum
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         bool inRange(const float value) const;
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         // Updates the text in the edit box
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
         void setString(const String& str);
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     public:
 
         SignalFloat onValueChange = {"ValueChanged"}; //!< Value of the spin control changed. Optional parameter: new value
 
-
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     protected:
 
         unsigned int m_decimalPlaces = 0;
-        bool m_useWideArrows = false;
+        bool m_useWideArrows = false; // TGUI_NEXT: Remove
+        AbsoluteOrRelativeValue m_spinButtonWidth;
 
         /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     private:
