@@ -22,9 +22,10 @@
 //
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-
 #include <TGUI/CustomWidgetForBindings.hpp>
 
+#ifndef TGUI_REMOVE_DEPRECATED_CODE
+
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 namespace tgui
@@ -244,4 +245,6 @@ namespace tgui
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 }
 
+#endif // TGUI_REMOVE_DEPRECATED_CODE
+
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
