@@ -43,9 +43,6 @@ namespace tgui
     ScrollablePanel::ScrollablePanel(const char* typeName, bool initRenderer) :
         Panel{typeName, false}
     {
-        // Rotate the horizontal scrollbar
-        m_horizontalScrollbar->setSize(m_horizontalScrollbar->getSize().y, m_horizontalScrollbar->getSize().x);
-
         if (initRenderer)
         {
             m_renderer = aurora::makeCopied<ScrollablePanelRenderer>();
@@ -57,16 +54,15 @@ namespace tgui
 
     ScrollablePanel::ScrollablePanel(const ScrollablePanel& other) :
         Panel                       {other},
+        DualScrollbarChildInterface {other},
         m_contentSize               {other.m_contentSize},
         m_mostBottomRightPosition   {other.m_mostBottomRightPosition},
-        m_verticalScrollbar         {other.m_verticalScrollbar},
-        m_horizontalScrollbar       {other.m_horizontalScrollbar},
-        m_verticalScrollbarPolicy   {other.m_verticalScrollbarPolicy},
-        m_horizontalScrollbarPolicy {other.m_horizontalScrollbarPolicy},
         m_verticalScrollAmount      {other.m_verticalScrollAmount},
         m_horizontalScrollAmount    {other.m_horizontalScrollAmount},
         m_verticalScrollbarWasVisibleOnSizeUpdate{other.m_verticalScrollbarWasVisibleOnSizeUpdate},
         m_horizontalScrollbarWasVisibleOnSizeUpdate{other.m_horizontalScrollbarWasVisibleOnSizeUpdate},
+        m_recalculatingSizeDuringUpdateScrollbars{false},
+        m_stuckInUpdateScrollbars   {false},
         m_connectedPositionCallbacks{},
         m_connectedSizeCallbacks    {}
     {
@@ -81,16 +77,15 @@ namespace tgui
 
     ScrollablePanel::ScrollablePanel(ScrollablePanel&& other) noexcept :
         Panel                       {std::move(other)},
+        DualScrollbarChildInterface {std::move(other)},
         m_contentSize               {std::move(other.m_contentSize)},
         m_mostBottomRightPosition   {std::move(other.m_mostBottomRightPosition)},
-        m_verticalScrollbar         {std::move(other.m_verticalScrollbar)},
-        m_horizontalScrollbar       {std::move(other.m_horizontalScrollbar)},
-        m_verticalScrollbarPolicy   {std::move(other.m_verticalScrollbarPolicy)},
-        m_horizontalScrollbarPolicy {std::move(other.m_horizontalScrollbarPolicy)},
         m_verticalScrollAmount      {std::move(other.m_verticalScrollAmount)},
         m_horizontalScrollAmount    {std::move(other.m_horizontalScrollAmount)},
         m_verticalScrollbarWasVisibleOnSizeUpdate{std::move(other.m_verticalScrollbarWasVisibleOnSizeUpdate)},
         m_horizontalScrollbarWasVisibleOnSizeUpdate{std::move(other.m_horizontalScrollbarWasVisibleOnSizeUpdate)},
+        m_recalculatingSizeDuringUpdateScrollbars{false},
+        m_stuckInUpdateScrollbars   {false},
         m_connectedPositionCallbacks{std::move(other.m_connectedPositionCallbacks)},
         m_connectedSizeCallbacks    {std::move(other.m_connectedSizeCallbacks)}
     {
@@ -110,16 +105,15 @@ namespace tgui
         if (this != &other)
         {
             Panel::operator=(other);
+            DualScrollbarChildInterface::operator=(other);
             m_contentSize               = other.m_contentSize;
             m_mostBottomRightPosition   = other.m_mostBottomRightPosition;
-            m_verticalScrollbar         = other.m_verticalScrollbar;
-            m_horizontalScrollbar       = other.m_horizontalScrollbar;
-            m_verticalScrollbarPolicy   = other.m_verticalScrollbarPolicy;
-            m_horizontalScrollbarPolicy = other.m_horizontalScrollbarPolicy;
             m_verticalScrollAmount      = other.m_verticalScrollAmount;
             m_horizontalScrollAmount    = other.m_horizontalScrollAmount;
             m_verticalScrollbarWasVisibleOnSizeUpdate = other.m_verticalScrollbarWasVisibleOnSizeUpdate;
             m_horizontalScrollbarWasVisibleOnSizeUpdate = other.m_horizontalScrollbarWasVisibleOnSizeUpdate;
+            m_recalculatingSizeDuringUpdateScrollbars = false;
+            m_stuckInUpdateScrollbars = false;
 
             disconnectAllChildWidgets();
 
@@ -141,15 +135,14 @@ namespace tgui
         {
             m_contentSize               = std::move(other.m_contentSize);
             m_mostBottomRightPosition   = std::move(other.m_mostBottomRightPosition);
-            m_verticalScrollbar         = std::move(other.m_verticalScrollbar);
-            m_horizontalScrollbar       = std::move(other.m_horizontalScrollbar);
-            m_verticalScrollbarPolicy   = std::move(other.m_verticalScrollbarPolicy);
-            m_horizontalScrollbarPolicy = std::move(other.m_horizontalScrollbarPolicy);
             m_verticalScrollAmount      = std::move(other.m_verticalScrollAmount);
             m_horizontalScrollAmount    = std::move(other.m_horizontalScrollAmount);
-            m_verticalScrollbarWasVisibleOnSizeUpdate = other.m_verticalScrollbarWasVisibleOnSizeUpdate;
-            m_horizontalScrollbarWasVisibleOnSizeUpdate = other.m_horizontalScrollbarWasVisibleOnSizeUpdate;
+            m_verticalScrollbarWasVisibleOnSizeUpdate = std::move(other.m_verticalScrollbarWasVisibleOnSizeUpdate);
+            m_horizontalScrollbarWasVisibleOnSizeUpdate = std::move(other.m_horizontalScrollbarWasVisibleOnSizeUpdate);
+            m_recalculatingSizeDuringUpdateScrollbars = false;
+            m_stuckInUpdateScrollbars = false;
             Panel::operator=(std::move(other));
+            DualScrollbarChildInterface::operator=(std::move(other));
 
             disconnectAllChildWidgets();
 
@@ -239,9 +232,8 @@ namespace tgui
             if (bottomRight.y > m_mostBottomRightPosition.y)
                 m_mostBottomRightPosition.y = bottomRight.y;
 
-            updateScrollbars();
-
             connectPositionAndSize(widget);
+            updateScrollbars();
         }
     }
 
@@ -322,9 +314,9 @@ namespace tgui
     {
         Vector2f size = Panel::getInnerSize();
         if (m_verticalScrollbar->isShown())
-            size.x -= std::min(size.x, getScrollbarWidth());
+            size.x -= std::min(size.x, getVerticalScrollbar()->getWidth());
         if (m_horizontalScrollbar->isShown())
-            size.y -= std::min(size.y, getScrollbarWidth());
+            size.y -= std::min(size.y, getHorizontalScrollbar()->getWidth());
         return size;
     }
 
@@ -358,62 +350,28 @@ namespace tgui
 
     void ScrollablePanel::setVerticalScrollbarPolicy(Scrollbar::Policy policy)
     {
-        m_verticalScrollbarPolicy = policy;
-
-        if (policy == Scrollbar::Policy::Always)
-        {
-            m_verticalScrollbar->setVisible(true);
-            m_verticalScrollbar->setAutoHide(false);
-        }
-        else if (policy == Scrollbar::Policy::Never)
-        {
-            m_verticalScrollbar->setVisible(false);
-        }
-        else // Scrollbar::Policy::Automatic
-        {
-            m_verticalScrollbar->setVisible(true);
-            m_verticalScrollbar->setAutoHide(true);
-        }
-
-        updateScrollbars();
+        getVerticalScrollbar()->setPolicy(policy);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     Scrollbar::Policy ScrollablePanel::getVerticalScrollbarPolicy() const
     {
-        return m_verticalScrollbarPolicy;
+        return m_verticalScrollbar->getPolicy();
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void ScrollablePanel::setHorizontalScrollbarPolicy(Scrollbar::Policy policy)
     {
-        m_horizontalScrollbarPolicy = policy;
-
-        if (policy == Scrollbar::Policy::Always)
-        {
-            m_horizontalScrollbar->setVisible(true);
-            m_horizontalScrollbar->setAutoHide(false);
-        }
-        else if (policy == Scrollbar::Policy::Never)
-        {
-            m_horizontalScrollbar->setVisible(false);
-        }
-        else // Scrollbar::Policy::Automatic
-        {
-            m_horizontalScrollbar->setVisible(true);
-            m_horizontalScrollbar->setAutoHide(true);
-        }
-
-        updateScrollbars();
+        getHorizontalScrollbar()->setPolicy(policy);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     Scrollbar::Policy ScrollablePanel::getHorizontalScrollbarPolicy() const
     {
-        return m_horizontalScrollbarPolicy;
+        return m_horizontalScrollbar->getPolicy();
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -442,10 +400,7 @@ namespace tgui
         m_horizontalScrollAmount = scrollAmount;
 
         if (scrollAmount == 0)
-        {
-            const float horizontalSpeed = 40.f * (static_cast<float>(m_horizontalScrollbar->getMaximum() - m_horizontalScrollbar->getViewportSize()) / m_horizontalScrollbar->getViewportSize());
-            m_horizontalScrollbar->setScrollAmount(static_cast<unsigned int>(std::ceil(std::sqrt(horizontalSpeed))));
-        }
+            m_horizontalScrollbar->setScrollAmount(getGlobalTextSize() * 5);
         else
             m_horizontalScrollbar->setScrollAmount(scrollAmount);
     }
@@ -596,13 +551,10 @@ namespace tgui
 
     bool ScrollablePanel::scrolled(float delta, Vector2f pos, bool touch)
     {
-        const bool horizontalScrollbarVisible = m_horizontalScrollbar->isVisible() && (!m_horizontalScrollbar->getAutoHide() || (m_horizontalScrollbar->getMaximum() > m_horizontalScrollbar->getViewportSize()));
-        const bool verticalScrollbarVisible = m_verticalScrollbar->isVisible() && (!m_verticalScrollbar->getAutoHide() || (m_verticalScrollbar->getMaximum() > m_verticalScrollbar->getViewportSize()));
-
         Vector2f innerSize = getInnerSize();
-        if (verticalScrollbarVisible)
+        if (m_verticalScrollbar->isShown())
             innerSize.x -= m_verticalScrollbar->getSize().x;
-        if (horizontalScrollbarVisible)
+        if (m_horizontalScrollbar->isShown())
             innerSize.y -= m_horizontalScrollbar->getSize().y;
 
         // If we are scrolling through the panel and it causes the mouse to end up on a scrollable child widget,
@@ -622,14 +574,16 @@ namespace tgui
         }
 
         // If the scroll event wasn't handled by a child widget then pass them to the scrollbars in this panel
+        const bool horizontalScrollbarCanMove = (m_horizontalScrollbar->getViewportSize() < m_horizontalScrollbar->getMaximum());
+        const bool verticalScrollbarCanMove = (m_verticalScrollbar->getViewportSize() < m_verticalScrollbar->getMaximum());
         bool scrollbarMoved = false;
-        if (m_horizontalScrollbar->isShown()
+        if (horizontalScrollbarCanMove
          && !touch
-         && (!m_verticalScrollbar->isShown() || m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()) || keyboard::isShiftPressed()))
+         && (!verticalScrollbarCanMove || m_horizontalScrollbar->isMouseOnWidget(pos - getPosition()) || keyboard::isShiftPressed(m_parentGui)))
         {
             scrollbarMoved = m_horizontalScrollbar->scrolled(delta, pos - getPosition(), touch);
         }
-        else if (m_verticalScrollbar->isShown())
+        else if (verticalScrollbarCanMove)
         {
             scrollbarMoved = m_verticalScrollbar->scrolled(delta, pos - getPosition(), touch);
         }
@@ -722,9 +676,9 @@ namespace tgui
         Vector2f contentSize = {innerSize.x - m_paddingCached.getLeft() - m_paddingCached.getRight(),
                                 innerSize.y - m_paddingCached.getTop() - m_paddingCached.getBottom()};
 
-        if (m_verticalScrollbar->isVisible() && (m_verticalScrollbar->getMaximum() > m_verticalScrollbar->getViewportSize()))
+        if (m_verticalScrollbar->isShown())
             contentSize.x -= m_verticalScrollbar->getSize().x;
-        if (m_horizontalScrollbar->isVisible() && (m_horizontalScrollbar->getMaximum() > m_horizontalScrollbar->getViewportSize()))
+        if (m_horizontalScrollbar->isShown())
             contentSize.y -= m_horizontalScrollbar->getSize().y;
 
         // If the content size is manually specified and smaller than the panel itself, then use it for clipping
@@ -744,11 +698,8 @@ namespace tgui
             target.removeClippingLayer();
         }
 
-        if (m_verticalScrollbar->isVisible())
-            m_verticalScrollbar->draw(target, oldStates);
-
-        if (m_horizontalScrollbar->isVisible())
-            m_horizontalScrollbar->draw(target, oldStates);
+        m_verticalScrollbar->draw(target, oldStates);
+        m_horizontalScrollbar->draw(target, oldStates);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -764,18 +715,25 @@ namespace tgui
             if (getSharedRenderer()->getScrollbarWidth() == 0)
             {
                 const float width = m_verticalScrollbar->getDefaultWidth();
-                m_verticalScrollbar->setSize({width, m_verticalScrollbar->getSize().y});
-                m_horizontalScrollbar->setSize({m_horizontalScrollbar->getSize().x, width});
+                m_verticalScrollbar->setWidth(width);
+                m_horizontalScrollbar->setHeight(width);
                 updateScrollbars();
             }
         }
         else if (property == U"ScrollbarWidth")
         {
             const float width = (getSharedRenderer()->getScrollbarWidth() != 0) ? getSharedRenderer()->getScrollbarWidth() : m_verticalScrollbar->getDefaultWidth();
-            m_verticalScrollbar->setSize({width, m_verticalScrollbar->getSize().y});
-            m_horizontalScrollbar->setSize({m_horizontalScrollbar->getSize().x, width});
+            m_verticalScrollbar->setWidth(width);
+            m_horizontalScrollbar->setHeight(width);
             updateScrollbars();
         }
+        else if ((property == U"Opacity") || (property == U"OpacityDisabled"))
+        {
+            Widget::rendererChanged(property);
+
+            m_verticalScrollbar->setInheritedOpacity(m_opacityCached);
+            m_horizontalScrollbar->setInheritedOpacity(m_opacityCached);
+        }
         else
             Panel::rendererChanged(property);
     }
@@ -785,23 +743,10 @@ namespace tgui
     std::unique_ptr<DataIO::Node> ScrollablePanel::save(SavingRenderersMap& renderers) const
     {
         auto node = Panel::save(renderers);
-
-        if (m_verticalScrollbarPolicy != Scrollbar::Policy::Automatic)
-        {
-            if (m_verticalScrollbarPolicy == Scrollbar::Policy::Always)
-                node->propertyValuePairs[U"VerticalScrollbarPolicy"] = std::make_unique<DataIO::ValueNode>("Always");
-            else if (m_verticalScrollbarPolicy == Scrollbar::Policy::Never)
-                node->propertyValuePairs[U"VerticalScrollbarPolicy"] = std::make_unique<DataIO::ValueNode>("Never");
-        }
-        if (m_horizontalScrollbarPolicy != Scrollbar::Policy::Automatic)
-        {
-            if (m_horizontalScrollbarPolicy == Scrollbar::Policy::Always)
-                node->propertyValuePairs[U"HorizontalScrollbarPolicy"] = std::make_unique<DataIO::ValueNode>("Always");
-            else if (m_horizontalScrollbarPolicy == Scrollbar::Policy::Never)
-                node->propertyValuePairs[U"HorizontalScrollbarPolicy"] = std::make_unique<DataIO::ValueNode>("Never");
-        }
-
         node->propertyValuePairs[U"ContentSize"] = std::make_unique<DataIO::ValueNode>(U"(" + String::fromNumber(m_contentSize.x) + U", " + String::fromNumber(m_contentSize.y) + U")");
+
+        saveScrollbarPolicies(node);
+
         return node;
     }
 
@@ -814,31 +759,24 @@ namespace tgui
         if (node->propertyValuePairs[U"ContentSize"])
             setContentSize(Vector2f{node->propertyValuePairs[U"ContentSize"]->value});
 
-        if (node->propertyValuePairs[U"VerticalScrollbarPolicy"])
-        {
-            String policy = node->propertyValuePairs[U"VerticalScrollbarPolicy"]->value.trim();
-            if (policy == U"Automatic")
-                setVerticalScrollbarPolicy(Scrollbar::Policy::Automatic);
-            else if (policy == U"Always")
-                setVerticalScrollbarPolicy(Scrollbar::Policy::Always);
-            else if (policy == U"Never")
-                setVerticalScrollbarPolicy(Scrollbar::Policy::Never);
-            else
-                throw Exception{U"Failed to parse VerticalScrollbarPolicy property, found unknown value '" + policy + U"'."};
-        }
+        loadScrollbarPolicies(node);
+    }
 
-        if (node->propertyValuePairs[U"HorizontalScrollbarPolicy"])
-        {
-            String policy = node->propertyValuePairs[U"HorizontalScrollbarPolicy"]->value.trim();
-            if (policy == U"Automatic")
-                setHorizontalScrollbarPolicy(Scrollbar::Policy::Automatic);
-            else if (policy == U"Always")
-                setHorizontalScrollbarPolicy(Scrollbar::Policy::Always);
-            else if (policy == U"Never")
-                setHorizontalScrollbarPolicy(Scrollbar::Policy::Never);
-            else
-                throw Exception{U"Failed to parse HorizontalScrollbarPolicy property, found unknown value '" + policy + U"'."};
-        }
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void ScrollablePanel::scrollbarPolicyChanged(Orientation)
+    {
+        updateScrollbars();
+    }
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+    void ScrollablePanel::scrollbarScrollAmountChanged(Orientation orientation)
+    {
+        if (orientation == Orientation::Vertical)
+            m_verticalScrollAmount = m_verticalScrollbar->getScrollAmount();
+        else
+            m_horizontalScrollAmount = m_horizontalScrollbar->getScrollAmount();
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -853,17 +791,28 @@ namespace tgui
         m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(visibleSize.y));
 
         const Vector2f contentSize = getContentSize();
-        m_horizontalScrollbar->setMaximum(static_cast<unsigned int>(contentSize.x));
-        m_verticalScrollbar->setMaximum(static_cast<unsigned int>(contentSize.y));
+        if (m_stuckInUpdateScrollbars)
+        {
+            // If the user resizes widgets based on the panel's content size then they will be resized when a scrollbar becomes visible.
+            // It is possible for the widget to change to a size where the scrollbar is no longer needed. If we were to hide the scrollbar
+            // then this would lead to an infinite cycle. So if the scrollbars are updated while an update is already busy, then we will
+            // never shrink the scrollable space.
+            m_horizontalScrollbar->setMaximum(std::max(m_horizontalScrollbar->getMaximum(), static_cast<unsigned int>(contentSize.x)));
+            m_verticalScrollbar->setMaximum(std::max(m_verticalScrollbar->getMaximum(), static_cast<unsigned int>(contentSize.y)));
+        }
+        else
+        {
+            m_horizontalScrollbar->setMaximum(static_cast<unsigned int>(contentSize.x));
+            m_verticalScrollbar->setMaximum(static_cast<unsigned int>(contentSize.y));
+        }
 
-        const bool horizontalScrollbarVisible = m_horizontalScrollbar->isVisible() && (!m_horizontalScrollbar->getAutoHide() || (m_horizontalScrollbar->getMaximum() > m_horizontalScrollbar->getViewportSize()));
+        const bool horizontalScrollbarVisible = m_horizontalScrollbar->isShown();
         if (horizontalScrollbarVisible)
         {
             m_verticalScrollbar->setSize(m_verticalScrollbar->getSize().x, scrollbarSpace.y - m_horizontalScrollbar->getSize().y);
             m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(m_verticalScrollbar->getViewportSize() - m_horizontalScrollbar->getSize().y));
 
-            const bool verticalScrollbarVisible = m_verticalScrollbar->isVisible() && (!m_verticalScrollbar->getAutoHide() || (m_verticalScrollbar->getMaximum() > m_verticalScrollbar->getViewportSize()));
-            if (verticalScrollbarVisible)
+            if (m_verticalScrollbar->isShown())
             {
                 m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(m_horizontalScrollbar->getViewportSize() - m_verticalScrollbar->getSize().x));
                 m_horizontalScrollbar->setSize(scrollbarSpace.x - m_verticalScrollbar->getSize().x, m_horizontalScrollbar->getSize().y);
@@ -874,15 +823,16 @@ namespace tgui
         else
         {
             m_verticalScrollbar->setSize(m_verticalScrollbar->getSize().x, scrollbarSpace.y);
-
-            const bool verticalScrollbarVisible = m_verticalScrollbar->isVisible() && (!m_verticalScrollbar->getAutoHide() || (m_verticalScrollbar->getMaximum() > m_verticalScrollbar->getViewportSize()));
-            if (verticalScrollbarVisible)
+            if (m_verticalScrollbar->isShown())
             {
                 m_horizontalScrollbar->setSize(scrollbarSpace.x - m_verticalScrollbar->getSize().x, m_horizontalScrollbar->getSize().y);
                 m_horizontalScrollbar->setViewportSize(static_cast<unsigned int>(m_horizontalScrollbar->getViewportSize() - m_verticalScrollbar->getSize().x));
 
-                if (m_horizontalScrollbar->isVisible() && (!m_horizontalScrollbar->getAutoHide() || (m_horizontalScrollbar->getMaximum() > m_horizontalScrollbar->getViewportSize())))
+                if (m_horizontalScrollbar->isShown())
+                {
                     m_verticalScrollbar->setSize(m_verticalScrollbar->getSize().x, scrollbarSpace.y - m_horizontalScrollbar->getSize().y);
+                    m_verticalScrollbar->setViewportSize(static_cast<unsigned int>(m_verticalScrollbar->getViewportSize() - m_horizontalScrollbar->getSize().y));
+                }
             }
             else
                 m_horizontalScrollbar->setSize(scrollbarSpace.x, m_horizontalScrollbar->getSize().y);
@@ -892,16 +842,29 @@ namespace tgui
         m_horizontalScrollbar->setPosition(m_bordersCached.getLeft(), m_bordersCached.getTop() + scrollbarSpace.y - m_horizontalScrollbar->getSize().y);
 
         if (m_verticalScrollAmount == 0)
-            setVerticalScrollAmount(0);
+            m_verticalScrollbar->setScrollAmount(getGlobalTextSize() * 5);
 
         if (m_horizontalScrollAmount == 0)
-            setHorizontalScrollAmount(0);
+            m_horizontalScrollbar->setScrollAmount(getGlobalTextSize() * 5);
 
-        if ((m_horizontalScrollbarWasVisibleOnSizeUpdate != m_horizontalScrollbar->isShown()) || (m_verticalScrollbarWasVisibleOnSizeUpdate != m_verticalScrollbar->isShown()))
+        const bool horizontalScrollbarShown = m_horizontalScrollbar->isShown();
+        const bool verticalScrollbarShown = m_verticalScrollbar->isShown();
+        if ((m_horizontalScrollbarWasVisibleOnSizeUpdate != horizontalScrollbarShown) || (m_verticalScrollbarWasVisibleOnSizeUpdate != verticalScrollbarShown))
         {
-            m_horizontalScrollbarWasVisibleOnSizeUpdate = m_horizontalScrollbar->isShown();
-            m_verticalScrollbarWasVisibleOnSizeUpdate = m_verticalScrollbar->isShown();
+            // We will allow widgets to update once when the scrollbars become visible or are hidden.
+            // If we reach this point a second time, then changing the scrollbars affected the widgets
+            // so that the scrollbars would need to be updated again. To break out of the infinite loop
+            // of showing and hiding the scrollbars, we will stop shrinking the content area even if
+            // the widgets shrink during the update.
+            if (m_recalculatingSizeDuringUpdateScrollbars)
+                m_stuckInUpdateScrollbars = true;
+
+            m_recalculatingSizeDuringUpdateScrollbars = true;
+            m_horizontalScrollbarWasVisibleOnSizeUpdate = horizontalScrollbarShown;
+            m_verticalScrollbarWasVisibleOnSizeUpdate = verticalScrollbarShown;
             recalculateBoundSizeLayouts();
+            m_recalculatingSizeDuringUpdateScrollbars = false;
+            m_stuckInUpdateScrollbars = false;
         }
     }
 
