@@ -101,10 +101,13 @@ namespace tgui
 
         m_bordersCached.updateParentSize(getSize());
 
-        if (getSize().x < getSize().y)
-            m_orientation = Orientation::Vertical;
-        else if (getSize().x > getSize().y)
-            m_orientation = Orientation::Horizontal;
+        if (!m_orientationLocked)
+        {
+            if (getSize().x < getSize().y)
+                m_orientation = Orientation::Vertical;
+            else if (getSize().x > getSize().y)
+                m_orientation = Orientation::Horizontal;
+        }
 
         if (m_spriteTrack.isSet())
         {
@@ -320,10 +323,16 @@ namespace tgui
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-#ifndef TGUI_REMOVE_DEPRECATED_CODE
+
     void Slider::setVerticalScroll(bool vertical)
     {
-        setOrientation(vertical ? Orientation::Vertical : Orientation::Horizontal);
+        m_orientationLocked = false;
+        const Orientation orientation = vertical ? Orientation::Vertical : Orientation::Horizontal;
+        if (m_orientation == orientation)
+            return;
+
+        m_orientation = orientation;
+        setSize(getSize().y, getSize().x);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -332,16 +341,13 @@ namespace tgui
     {
         return m_orientation == Orientation::Vertical;
     }
-#endif
+
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void Slider::setOrientation(Orientation orientation)
     {
-        if (m_orientation == orientation)
-            return;
-
+        m_orientationLocked = true;
         m_orientation = orientation;
-        setSize(getSize().y, getSize().x);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
