@@ -47,7 +47,7 @@ namespace tgui
             setRenderer(Theme::getDefault()->getRendererNoThrow(m_type));
         }
 
-        setSize(20, 42);
+        setSize(21, 42);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -101,10 +101,13 @@ namespace tgui
 
         m_bordersCached.updateParentSize(getSize());
 
-        if (getSize().x < getSize().y)
-            m_orientation = Orientation::Vertical;
-        else if (getSize().x > getSize().y)
-            m_orientation = Orientation::Horizontal;
+        if (!m_orientationLocked)
+        {
+            if (getSize().x < getSize().y)
+                m_orientation = Orientation::Vertical;
+            else if (getSize().x > getSize().y)
+                m_orientation = Orientation::Horizontal;
+        }
 
         if (m_orientation == Orientation::Vertical)
         {
@@ -216,10 +219,16 @@ namespace tgui
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-#ifndef TGUI_REMOVE_DEPRECATED_CODE
+
     void SpinButton::setVerticalScroll(bool vertical)
     {
-        setOrientation(vertical ? Orientation::Vertical : Orientation::Horizontal);
+        m_orientationLocked = false;
+        const Orientation orientation = vertical ? Orientation::Vertical : Orientation::Horizontal;
+        if (m_orientation == orientation)
+            return;
+
+        m_orientation = orientation;
+        setSize(getSize().y, getSize().x);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -228,16 +237,13 @@ namespace tgui
     {
         return m_orientation == Orientation::Vertical;
     }
-#endif
+
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
     void SpinButton::setOrientation(Orientation orientation)
     {
-        if (m_orientation == orientation)
-            return;
-
+        m_orientationLocked = true;
         m_orientation = orientation;
-        setSize(getSize().y, getSize().x);
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -482,9 +488,9 @@ namespace tgui
                 target.drawFilledRect(states, {arrowSize.y, arrowSize.x}, arrowBackColor);
 
                 target.drawTriangle(states,
-                    {{arrowSize.x * 4/5, arrowSize.y / 5}, arrowVertexColor},
-                    {{arrowSize.x / 5, arrowSize.y / 2}, arrowVertexColor},
-                    {{arrowSize.x * 4/5, arrowSize.y * 4/5}, arrowVertexColor}
+                    {{arrowSize.y * 4/5, arrowSize.x / 5}, arrowVertexColor},
+                    {{arrowSize.y / 5, arrowSize.x / 2}, arrowVertexColor},
+                    {{arrowSize.y * 4/5, arrowSize.x * 4/5}, arrowVertexColor}
                 );
             }
         }
@@ -548,9 +554,9 @@ namespace tgui
                 target.drawFilledRect(states, {arrowSize.y, arrowSize.x}, arrowBackColor);
 
                 target.drawTriangle(states,
-                    {{arrowSize.x / 5, arrowSize.y / 5}, arrowVertexColor},
-                    {{arrowSize.x * 4/5, arrowSize.y / 2}, arrowVertexColor},
-                    {{arrowSize.x / 5, arrowSize.y * 4/5}, arrowVertexColor}
+                    {{arrowSize.y / 5, arrowSize.x / 5}, arrowVertexColor},
+                    {{arrowSize.y * 4/5, arrowSize.x / 2}, arrowVertexColor},
+                    {{arrowSize.y / 5, arrowSize.x * 4/5}, arrowVertexColor}
                 );
             }
         }
