@@ -601,12 +601,13 @@ namespace tgui
 
         parentNodes->erase(parentNodes->begin() + static_cast<std::ptrdiff_t>(currentIndex));
         parentNodes->insert(parentNodes->begin() + static_cast<std::ptrdiff_t>(index), node);
+        markNodesDirty();
         return true;
     }
 
     /////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
-    int TreeView::getItemIndexInParent(const std::vector<String>& hierarchy)
+    int TreeView::getItemIndexInParent(const std::vector<String>& hierarchy) const
     {
         if (hierarchy.empty())
             return -1;
@@ -669,6 +670,7 @@ namespace tgui
         // Update the moved node
         node->text.setString(newHierarchy.back());
         node->parent = newParentNode;
+        markNodesDirty();
         return true;
     }
 
