@@ -131,30 +131,95 @@ TEST_CASE("[Scrollbar]")
         REQUIRE(scrollbar->getScrollAmount() == 50);
     }
 
-    SECTION("AutoHide")
+    SECTION("Policy")
     {
-        REQUIRE(scrollbar->getAutoHide());
-        scrollbar->setAutoHide(false);
-        REQUIRE(!scrollbar->getAutoHide());
-        scrollbar->setAutoHide(true);
-        REQUIRE(scrollbar->getAutoHide());
+        REQUIRE(scrollbar->getPolicy() == tgui::Scrollbar::Policy::Automatic);
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Always);
+        REQUIRE(scrollbar->getPolicy() == tgui::Scrollbar::Policy::Always);
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Never);
+        REQUIRE(scrollbar->getPolicy() == tgui::Scrollbar::Policy::Never);
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Automatic);
+        REQUIRE(scrollbar->getPolicy() == tgui::Scrollbar::Policy::Automatic);
+    }
+
+    SECTION("isShown")
+    {
+        scrollbar->setViewportSize(5);
+        scrollbar->setMaximum(5);
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Always);
+        REQUIRE(scrollbar->isShown());
+
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Automatic);
+        REQUIRE(!scrollbar->isShown());
+
+        scrollbar->setMaximum(10);
+        REQUIRE(scrollbar->isShown());
+
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Never);
+        REQUIRE(!scrollbar->isShown());
+
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Always);
+        REQUIRE(scrollbar->isShown());
+
+        scrollbar->setVisible(false);
+        REQUIRE(!scrollbar->isShown());
     }
 
     SECTION("Orientation")
     {
-        scrollbar->setSize(100, 20);
-        REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
-
-        scrollbar->setSize(20, 100);
         REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
 
-        scrollbar->setSize(10, 40);
-        scrollbar->setOrientation(tgui::Orientation::Horizontal);
-        REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
-        REQUIRE(scrollbar->getSize() == tgui::Vector2f(40, 10));
-        scrollbar->setOrientation(tgui::Orientation::Vertical);
-        REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
-        REQUIRE(scrollbar->getSize() == tgui::Vector2f(10, 40));
+        SECTION("Deprecated setVerticalScroll method")
+        {
+            REQUIRE(scrollbar->getVerticalScroll());
+
+            scrollbar->setSize(100, 20);
+            REQUIRE(!scrollbar->getVerticalScroll());
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+
+            scrollbar->setSize(20, 100);
+            REQUIRE(scrollbar->getVerticalScroll());
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
+
+            scrollbar->setSize(10, 40);
+            scrollbar->setVerticalScroll(false);
+            REQUIRE(!scrollbar->getVerticalScroll());
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+            REQUIRE(scrollbar->getSize() == tgui::Vector2f(40, 10)); // setVerticalScroll flips size
+            scrollbar->setVerticalScroll(true);
+            REQUIRE(scrollbar->getVerticalScroll());
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
+            REQUIRE(scrollbar->getSize() == tgui::Vector2f(10, 40)); // setVerticalScroll flips size
+
+            // Orientation isn't locked, calling setSize can still alter the orientation
+            scrollbar->setSize(100, 20);
+            REQUIRE(!scrollbar->getVerticalScroll());
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+        }
+
+        SECTION("New setOrientation method")
+        {
+            scrollbar->setSize(100, 20);
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+
+            scrollbar->setSize(20, 100);
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
+
+            scrollbar->setSize(10, 40);
+            scrollbar->setOrientation(tgui::Orientation::Horizontal);
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+            REQUIRE(scrollbar->getSize() == tgui::Vector2f(10, 40)); // setOrientation does not alter size
+            scrollbar->setOrientation(tgui::Orientation::Vertical);
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Vertical);
+            REQUIRE(scrollbar->getSize() == tgui::Vector2f(10, 40)); // setOrientation does not alter size
+
+            scrollbar->setSize(100, 20);
+            scrollbar->setOrientation(tgui::Orientation::Horizontal);
+
+            // Orientation is locked, setSize no longer alters the orientation
+            scrollbar->setSize(20, 100);
+            REQUIRE(scrollbar->getOrientation() == tgui::Orientation::Horizontal);
+        }
     }
 
     SECTION("Events / Signals")
@@ -302,7 +367,7 @@ TEST_CASE("[Scrollbar]")
         scrollbar->setViewportSize(10);
         scrollbar->setValue(20);
         scrollbar->setScrollAmount(5);
-        scrollbar->setAutoHide(false);
+        scrollbar->setPolicy(tgui::Scrollbar::Policy::Always);
 
         testSavingWidget("Scrollbar", scrollbar);
     }
